@@ -7,37 +7,41 @@
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-
 #ifndef CMD_H
 #define CMD_H
 
 #include <QUndoCommand>
 
-#include "pos.h"
+#include "catalogstring.h"
 #include "note.h"
 #include "phase.h"
+#include "pos.h"
 #include "state.h"
-#include "catalogstring.h"
 class Catalog;
 
 enum Commands {
-    Insert, Delete,
-    InsertTag, DeleteTag,
-    ToggleApprovement, EquivTrans,
-    SetNote, UpdatePhase
+    Insert,
+    Delete,
+    InsertTag,
+    DeleteTag,
+    ToggleApprovement,
+    EquivTrans,
+    SetNote,
+    UpdatePhase,
 };
 
-class LokalizeUnitCmd: public QUndoCommand
+class LokalizeUnitCmd : public QUndoCommand
 {
 public:
-    LokalizeUnitCmd(Catalog *catalog, const DocPosition& pos, const QString& name);
+    LokalizeUnitCmd(Catalog *catalog, const DocPosition &pos, const QString &name);
     ~LokalizeUnitCmd() override = default;
     void undo() override;
     void redo() override;
-    DocPosition pos()const
+    DocPosition pos() const
     {
         return _pos;
     }
+
 protected:
     virtual void doRedo() = 0;
     virtual void doUndo() = 0;
@@ -46,20 +50,22 @@ protected:
      * alternatively customized pos may be set manually in do*()
      */
     virtual void setJumpingPos();
+
 protected:
-    Catalog* _catalog{nullptr};
+    Catalog *_catalog{nullptr};
     DocPosition _pos;
     bool _firstModificationForThisEntry{false};
-//    QString _prevPhase; currently xliffstorage doesn't support non-target phase setting
+    //    QString _prevPhase; currently xliffstorage doesn't support non-target phase setting
 };
 
-class LokalizeTargetCmd: public LokalizeUnitCmd
+class LokalizeTargetCmd : public LokalizeUnitCmd
 {
 public:
-    LokalizeTargetCmd(Catalog *catalog, const DocPosition& pos, const QString& name);
+    LokalizeTargetCmd(Catalog *catalog, const DocPosition &pos, const QString &name);
     ~LokalizeTargetCmd() override = default;
     void undo() override;
     void redo() override;
+
 protected:
     QString _prevTargetPhase;
 };
@@ -70,10 +76,10 @@ protected:
  * then set DocPosition (posBuffer var in Catalog), which is used to navigate editor to appr. place
  * @short Do insert text
  */
-class InsTextCmd: public LokalizeTargetCmd
+class InsTextCmd : public LokalizeTargetCmd
 {
 public:
-    InsTextCmd(Catalog *catalog, const DocPosition& pos, const QString& str);
+    InsTextCmd(Catalog *catalog, const DocPosition &pos, const QString &str);
     ~InsTextCmd() override = default;
     int id() const override
     {
@@ -82,15 +88,16 @@ public:
     bool mergeWith(const QUndoCommand *other) override;
     void doRedo() override;
     void doUndo() override;
+
 private:
     QString _str;
 };
 
 /// @see InsTextCmd
-class DelTextCmd: public LokalizeTargetCmd
+class DelTextCmd : public LokalizeTargetCmd
 {
 public:
-    DelTextCmd(Catalog *catalog, const DocPosition& pos, const QString& str);
+    DelTextCmd(Catalog *catalog, const DocPosition &pos, const QString &str);
     ~DelTextCmd() override = default;
     int id() const override
     {
@@ -99,14 +106,16 @@ public:
     bool mergeWith(const QUndoCommand *other) override;
     void doRedo() override;
     void doUndo() override;
+
 private:
     QString _str;
 };
 
-class SetStateCmd: public LokalizeUnitCmd
+class SetStateCmd : public LokalizeUnitCmd
 {
 private:
-    SetStateCmd(Catalog *catalog, const DocPosition& pos, TargetState state);
+    SetStateCmd(Catalog *catalog, const DocPosition &pos, TargetState state);
+
 public:
     ~SetStateCmd() override = default;
 
@@ -117,19 +126,19 @@ public:
     void doRedo() override;
     void doUndo() override;
 
-    static void push(Catalog *catalog, const DocPosition& pos, bool approved);
-    static void instantiateAndPush(Catalog *catalog, const DocPosition& pos, TargetState state);
+    static void push(Catalog *catalog, const DocPosition &pos, bool approved);
+    static void instantiateAndPush(Catalog *catalog, const DocPosition &pos, TargetState state);
 
     TargetState _state;
     TargetState _prevState{SignedOff};
 };
 
 /// @short Do insert tag
-class InsTagCmd: public LokalizeTargetCmd
+class InsTagCmd : public LokalizeTargetCmd
 {
 public:
     /// offset is taken from @a tag and not from @a pos
-    InsTagCmd(Catalog *catalog, const DocPosition& pos, const InlineTag& tag);
+    InsTagCmd(Catalog *catalog, const DocPosition &pos, const InlineTag &tag);
     ~InsTagCmd() override = default;
     int id() const override
     {
@@ -137,6 +146,7 @@ public:
     }
     void doRedo() override;
     void doUndo() override;
+
 private:
     InlineTag _tag;
 };
@@ -146,10 +156,10 @@ private:
  *
  * @short Do delete tag
  */
-class DelTagCmd: public LokalizeTargetCmd
+class DelTagCmd : public LokalizeTargetCmd
 {
 public:
-    DelTagCmd(Catalog *catalog, const DocPosition& pos);
+    DelTagCmd(Catalog *catalog, const DocPosition &pos);
     ~DelTagCmd() override = default;
     int id() const override
     {
@@ -157,40 +167,43 @@ public:
     }
     void doRedo() override;
     void doUndo() override;
-    InlineTag tag()const
+    InlineTag tag() const
     {
-        return _tag;   //used to get proprties of deleted tag
+        return _tag; // used to get proprties of deleted tag
     }
+
 private:
     InlineTag _tag;
 };
 
 /// @short Insert or remove (if content is empty) a note
-class SetNoteCmd: public LokalizeUnitCmd
+class SetNoteCmd : public LokalizeUnitCmd
 {
 public:
     /// @a pos.form is note number
-    SetNoteCmd(Catalog *catalog, const DocPosition& pos, const Note& note);
+    SetNoteCmd(Catalog *catalog, const DocPosition &pos, const Note &note);
     ~SetNoteCmd() override = default;
     int id() const override
     {
         return SetNote;
     }
+
 protected:
     void doRedo() override;
     void doUndo() override;
     void setJumpingPos() override;
+
 private:
     Note _note;
     Note _prevNote;
 };
 
 /// @short Add or remove (if content is empty) a phase
-class UpdatePhaseCmd: public QUndoCommand
+class UpdatePhaseCmd : public QUndoCommand
 {
 public:
     /// @a pos.form is note number
-    UpdatePhaseCmd(Catalog *catalog, const Phase& phase);
+    UpdatePhaseCmd(Catalog *catalog, const Phase &phase);
     ~UpdatePhaseCmd() override = default;
     int id() const override
     {
@@ -198,17 +211,17 @@ public:
     }
     void redo() override;
     void undo() override;
+
 private:
-    Catalog* _catalog{nullptr};
+    Catalog *_catalog{nullptr};
     Phase _phase;
     Phase _prevPhase;
 };
 
-
-class SetEquivTransCmd: public LokalizeTargetCmd
+class SetEquivTransCmd : public LokalizeTargetCmd
 {
 public:
-    SetEquivTransCmd(Catalog *catalog, const DocPosition& pos, bool equivTrans);
+    SetEquivTransCmd(Catalog *catalog, const DocPosition &pos, bool equivTrans);
     ~SetEquivTransCmd() override = default;
     int id() const override
     {
@@ -216,6 +229,7 @@ public:
     }
     void doRedo() override;
     void doUndo() override;
+
 private:
     bool _equivTrans{};
 };
@@ -228,8 +242,8 @@ private:
  * 1 means this is start, 2 means this is end
  * @returns false if it can't find second part of any paired tag in the range
  */
-bool fillTagPlaces(QMap<int, int>& tagPlaces, const CatalogString& catalogString, int start, int len);
-bool removeTargetSubstring(Catalog* catalog, DocPosition pos, int delStart = 0, int delLen = -1);
-void insertCatalogString(Catalog* catalog, DocPosition pos, const CatalogString& catStr, int start = 0);
+bool fillTagPlaces(QMap<int, int> &tagPlaces, const CatalogString &catalogString, int start, int len);
+bool removeTargetSubstring(Catalog *catalog, DocPosition pos, int delStart = 0, int delLen = -1);
+void insertCatalogString(Catalog *catalog, DocPosition pos, const CatalogString &catStr, int start = 0);
 
 #endif // CMD_H
