@@ -10,34 +10,27 @@
 */
 
 #include "editortab.h"
-
-#include "xlifftextedit.h"
-
-#include "lokalize_debug.h"
-
 #include "actionproxy.h"
-#include "catalog.h"
-#include "cmd.h"
-#include "editorview.h"
-
-#include "completionstorage.h"
-
-// views
 #include "alttransview.h"
 #include "binunitsview.h"
+#include "catalog.h"
 #include "cataloglistview.h"
+#include "cmd.h"
+#include "completionstorage.h"
+#include "editorview.h"
 #include "glossaryview.h"
+#include "languagelistmodel.h"
+#include "lokalize_debug.h"
+#include "lokalizetabpagebase.h"
 #include "mergeview.h"
 #include "msgctxtview.h"
-#include "tmview.h"
-
 #include "phaseswindow.h"
-#include "projectlocal.h"
-
-#include "languagelistmodel.h"
 #include "prefs.h"
 #include "prefs_lokalize.h"
 #include "project.h"
+#include "projectlocal.h"
+#include "tmview.h"
+#include "xlifftextedit.h"
 
 #include <KActionCategory>
 #include <KActionCollection>
@@ -57,22 +50,23 @@
 #include <QFileDialog>
 #include <QIcon>
 #include <QInputDialog>
-#include <QMdiArea>
 #include <QMenuBar>
+#include <QObject>
 #include <QProcess>
 #include <QStandardPaths>
 #include <QStringBuilder>
 #include <QTime>
 
 EditorTab::EditorTab(QWidget *parent, bool valid)
-    : LokalizeSubwindowBase2(parent)
+    : LokalizeTabPageBase(parent)
     , m_project(Project::instance())
     , m_catalog(new Catalog(this))
-    , m_view(new EditorView(this, m_catalog /*,new keyEventHandler(this,m_catalog)*/))
+    , m_view(new EditorView(this, m_catalog))
     , m_valid(valid)
 {
-    // QTime chrono;chrono.start();
-
+    m_defaultTabIcon = QIcon::fromTheme(QLatin1String("translate"));
+    m_unsavedTabIcon = QIcon::fromTheme(QLatin1String("document-save"));
+    m_tabIcon = m_defaultTabIcon;
     setAcceptDrops(true);
     setCentralWidget(m_view);
     setupStatusBar(); //--NOT called from initLater() !
@@ -91,10 +85,6 @@ EditorTab::EditorTab(QWidget *parent, bool valid)
     connect(this, &EditorTab::fileOpened, this, &EditorTab::indexWordsForCompletion, Qt::QueuedConnection);
 
     connect(m_catalog, &Catalog::signalFileAutoSaveFailed, this, &EditorTab::fileAutoSaveFailedWarning);
-
-    // defer some work to make window appear earlier (~200 msec on my Core Duo)
-    // QTimer::singleShot(0,this,SLOT(initLater()));
-    // qCWarning(LOKALIZE_LOG)<<chrono.elapsed();
 }
 
 void EditorTab::initLater()
@@ -129,22 +119,6 @@ void EditorTab::setupStatusBar()
     connect(m_catalog, &Catalog::signalNumberOfEmptyChanged, this, &EditorTab::numberOfUntranslatedChanged);
 }
 
-void LokalizeSubwindowBase::reflectNonApprovedCount(int count, int total)
-{
-    QString text = i18nc("@info:status message entries\n'fuzzy' in gettext terminology", "Not ready: %1", count);
-    if (count && total)
-        text += i18nc("percentages in statusbar", " (%1%)", int(100.0 * count / total));
-    statusBarItems.insert(ID_STATUS_FUZZY, text);
-}
-
-void LokalizeSubwindowBase::reflectUntranslatedCount(int count, int total)
-{
-    QString text = i18nc("@info:status message entries", "Untranslated: %1", count);
-    if (count && total)
-        text += i18nc("percentages in statusbar", " (%1%)", int(100.0 * count / total));
-    statusBarItems.insert(ID_STATUS_UNTRANS, text);
-}
-
 void EditorTab::numberOfFuzziesChanged()
 {
     reflectNonApprovedCount(m_catalog->numberOfNonApproved(), m_catalog->numberOfEntries());
@@ -174,7 +148,6 @@ void EditorTab::setupActions()
     KActionCategory *sync2 = new KActionCategory(i18n("Synchronization 2"), ac);
     KActionCategory *tm = new KActionCategory(i18n("Translation Memory"), ac);
     KActionCategory *glossary = new KActionCategory(i18nc("@title actions category", "Glossary"), ac);
-    // KActionCategory* tools=new KActionCategory(i18nc("@title actions category","Tools"), ac);
 
 #ifndef Q_OS_DARWIN
     QLocale::Language systemLang = QLocale::system().language();
@@ -191,16 +164,16 @@ void EditorTab::setupActions()
         altactions[i] = altaction;
     }
 
-    m_altTransView = new AltTransView(this, m_catalog, altactions);
-    addDockWidget(Qt::BottomDockWidgetArea, m_altTransView);
-    ac->addAction(QStringLiteral("showmsgiddiff_action"), m_altTransView->toggleViewAction());
+    m_alternateTranslationView = new AltTransView(this, m_catalog, altactions);
+    addDockWidget(Qt::BottomDockWidgetArea, m_alternateTranslationView);
+    ac->addAction(QStringLiteral("showmsgiddiff_action"), m_alternateTranslationView->toggleViewAction());
     connect(this,
             qOverload<const DocPosition &>(&EditorTab::signalNewEntryDisplayed),
-            m_altTransView,
+            m_alternateTranslationView,
             qOverload<const DocPosition &>(&AltTransView::slotNewEntryDisplayed));
-    connect(m_altTransView, &AltTransView::textInsertRequested, m_view, &EditorView::insertTerm);
-    connect(m_altTransView, &AltTransView::refreshRequested, m_view, qOverload<>(&EditorView::gotoEntry), Qt::QueuedConnection);
-    connect(m_catalog, qOverload<>(&Catalog::signalFileLoaded), m_altTransView, &AltTransView::fileLoaded);
+    connect(m_alternateTranslationView, &AltTransView::textInsertRequested, m_view, &EditorView::insertTerm);
+    connect(m_alternateTranslationView, &AltTransView::refreshRequested, m_view, qOverload<>(&EditorView::gotoEntry), Qt::QueuedConnection);
+    connect(m_catalog, qOverload<>(&Catalog::signalFileLoaded), m_alternateTranslationView, &AltTransView::fileLoaded);
 
     m_syncView = new MergeView(this, m_catalog, true);
     addDockWidget(Qt::BottomDockWidgetArea, m_syncView);
@@ -249,7 +222,6 @@ void EditorTab::setupActions()
     connect(m_view->viewPort(), &TranslationUnitTextEdit::languageToolChanged, m_notesView, &MsgCtxtView::languageTool);
 
     action = edit->addAction(QStringLiteral("edit_addnote"), m_notesView, SLOT(addNoteUI()));
-    // action->setShortcut(Qt::ControlModifier+glist[i]);
     action->setText(i18nc("@action:inmenu", "Add a note"));
 
     QVector<QAction *> tmactions_insert(TM_SHORTCUTS);
@@ -257,7 +229,6 @@ void EditorTab::setupActions()
     const Qt::Key tmlist[TM_SHORTCUTS] = {Qt::Key_1, Qt::Key_2, Qt::Key_3, Qt::Key_4, Qt::Key_5, Qt::Key_6, Qt::Key_7, Qt::Key_8, Qt::Key_9, Qt::Key_0};
     QAction *tmaction;
     for (int i = 0; i < TM_SHORTCUTS; ++i) {
-        //         action->setVisible(false);
         tmaction = tm->addAction(QStringLiteral("tmquery_insert_%1").arg(i));
         ac->setDefaultShortcut(tmaction, QKeySequence(Qt::ControlModifier | tmlist[i]));
         tmaction->setText(i18nc("@action:inmenu", "Insert TM suggestion #%1", i + 1));
@@ -277,18 +248,18 @@ void EditorTab::setupActions()
                                                       << QKeySequence(Qt::ControlModifier | Qt::AltModifier | Qt::Key_Plus));
     }
 #endif
-    TM::TMView *_tmView = new TM::TMView(this, m_catalog, tmactions_insert, tmactions_remove);
-    addDockWidget(Qt::BottomDockWidgetArea, _tmView);
-    tm->addAction(QStringLiteral("showtmqueryview_action"), _tmView->toggleViewAction());
-    connect(_tmView, &TM::TMView::refreshRequested, m_view, qOverload<>(&EditorView::gotoEntry), Qt::QueuedConnection);
-    connect(_tmView, &TM::TMView::refreshRequested, this, &EditorTab::msgStrChanged, Qt::QueuedConnection);
-    connect(_tmView, &TM::TMView::textInsertRequested, m_view, &EditorView::insertTerm);
-    connect(_tmView, &TM::TMView::fileOpenRequested, this, &EditorTab::fileOpenRequested);
+    m_translationMemoryView = new TM::TMView(this, m_catalog, tmactions_insert, tmactions_remove);
+    addDockWidget(Qt::BottomDockWidgetArea, m_translationMemoryView);
+    tm->addAction(QStringLiteral("showtmqueryview_action"), m_translationMemoryView->toggleViewAction());
+    connect(m_translationMemoryView, &TM::TMView::refreshRequested, m_view, qOverload<>(&EditorView::gotoEntry), Qt::QueuedConnection);
+    connect(m_translationMemoryView, &TM::TMView::refreshRequested, this, &EditorTab::msgStrChanged, Qt::QueuedConnection);
+    connect(m_translationMemoryView, &TM::TMView::textInsertRequested, m_view, &EditorView::insertTerm);
+    connect(m_translationMemoryView, &TM::TMView::fileOpenRequested, this, &EditorTab::fileOpenRequested);
     connect(this, &EditorTab::fileAboutToBeClosed, m_catalog, &Catalog::flushUpdateDBBuffer);
     connect(this, &EditorTab::signalNewEntryDisplayed, m_catalog, &Catalog::flushUpdateDBBuffer);
     connect(this,
             &EditorTab::signalNewEntryDisplayed,
-            _tmView,
+            m_translationMemoryView,
             qOverload<const DocPosition &>(&TM::TMView::slotNewEntryDisplayed)); // do this after flushUpdateDBBuffer
 
     QVector<QAction *> gactions(GLOSSARY_SHORTCUTS);
@@ -315,7 +286,6 @@ void EditorTab::setupActions()
                                                Qt::Key_Apostrophe};
     QAction *gaction;
     for (int i = 0; i < GLOSSARY_SHORTCUTS; ++i) {
-        //         action->setVisible(false);
         gaction = glossary->addAction(QStringLiteral("glossary_insert_%1").arg(i));
         ac->setDefaultShortcut(gaction, QKeySequence(Qt::ControlModifier | glist[i]));
         gaction->setText(i18nc("@action:inmenu", "Insert term translation #%1", QString::number(i)));
@@ -344,15 +314,9 @@ void EditorTab::setupActions()
 
     // File
     action = file->addAction(KStandardAction::Save, this, SLOT(saveFile()));
-    //    action->setEnabled(false);
-    //    connect (m_catalog,SIGNAL(cleanChanged(bool)),action,SLOT(setDisabled(bool)));
-    connect(m_catalog, &Catalog::cleanChanged, this, &EditorTab::setModificationSign);
+    connect(m_catalog, &Catalog::cleanChanged, this, &EditorTab::updateTabLabelAndIcon);
     file->addAction(KStandardAction::SaveAs, this, SLOT(saveFileAs()));
-    // action = KStandardAction::quit(qApp, SLOT(quit()), ac);
-    // action->setText(i18nc("@action:inmenu","Close all Lokalize windows"));
 
-    // KStandardAction::quit(kapp, SLOT(quit()), ac);
-    // KStandardAction::quit(this, SLOT(deleteLater()), ac);
 #define ADD_ACTION_SHORTCUT_ICON(_name, _text, _shortcut, _icon)                                                                                               \
     action = actionCategory->addAction(QStringLiteral(_name));                                                                                                 \
     action->setText(_text);                                                                                                                                    \
@@ -477,8 +441,6 @@ void EditorTab::setupActions()
     action = edit->addAction(QStringLiteral("edit_spellreplace"), m_view->viewPort(), SLOT(spellReplace()));
     ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::Key_Equal));
     action->setText(i18nc("@action:inmenu", "Replace with best spellcheck suggestion"));
-    //     action = ac->addAction("glossary_define",m_view,SLOT(defineNewTerm()));
-    //     action->setText(i18nc("@action:inmenu","Define new term"));
 
     // Go
     actionCategory = nav;
@@ -536,7 +498,7 @@ void EditorTab::setupActions()
 
     ADD_ACTION_SHORTCUT_ICON("go_prev_fuzzyUntr",
                              i18nc("@action:inmenu\n'not ready' means 'fuzzy' in gettext terminology", "Previous not ready"),
-                             Qt::ControlModifier | Qt::ShiftModifier /*ALT*/ | Qt::Key_PageUp,
+                             Qt::ControlModifier | Qt::ShiftModifier | Qt::Key_PageUp,
                              "prevfuzzyuntrans")
     connect(action, &QAction::triggered, this, &EditorTab::gotoPrevFuzzyUntr);
     connect(m_view->viewPort(), &TranslationUnitTextEdit::gotoPrevFuzzyUntrRequested, this, &EditorTab::gotoPrevFuzzyUntr);
@@ -556,10 +518,8 @@ void EditorTab::setupActions()
 
     // Bookmarks
     action = nav->addAction(KStandardAction::AddBookmark, m_view, SLOT(toggleBookmark(bool)));
-    // action = ac->addAction("bookmark_do");
     action->setText(i18nc("@option:check", "Bookmark message"));
     action->setCheckable(true);
-    // connect(action, SIGNAL(triggered(bool)),m_view,SLOT(toggleBookmark(bool)));
     connect(this, &EditorTab::signalBookmarkDisplayed, action, &QAction::setChecked);
 
     action = nav->addAction(QStringLiteral("bookmark_prior"), this, SLOT(gotoPrevBookmark()));
@@ -576,13 +536,13 @@ void EditorTab::setupActions()
     actionCategory = tm;
     // xgettext: no-c-format
     ADD_ACTION_SHORTCUT("tools_tm_batch", i18nc("@action:inmenu", "Fill in all exact suggestions"), Qt::ControlModifier | Qt::AltModifier | Qt::Key_B)
-    connect(action, &QAction::triggered, _tmView, &TM::TMView::slotBatchTranslate);
+    connect(action, &QAction::triggered, m_translationMemoryView, &TM::TMView::slotBatchTranslate);
 
     // xgettext: no-c-format
     ADD_ACTION_SHORTCUT("tools_tm_batch_fuzzy",
                         i18nc("@action:inmenu", "Fill in all exact suggestions and mark as fuzzy"),
                         Qt::ControlModifier | Qt::AltModifier | Qt::Key_N)
-    connect(action, &QAction::triggered, _tmView, &TM::TMView::slotBatchTranslateFuzzy);
+    connect(action, &QAction::triggered, m_translationMemoryView, &TM::TMView::slotBatchTranslateFuzzy);
 
     // MergeMode
     action = sync1->addAction(QStringLiteral("merge_open"), m_syncView, SLOT(mergeOpen()));
@@ -634,7 +594,6 @@ void EditorTab::setupActions()
     ac->setDefaultShortcut(action, QKeySequence(Qt::ControlModifier | Qt::AltModifier | Qt::Key_A));
     connect(m_syncView, &MergeView::mergeCatalogAvailable, action, &QAction::setEnabled);
     m_syncView->addAction(action);
-    // action->setShortcut(Qt::AltModifier+Qt::Key_E);
 
     action = sync1->addAction(QStringLiteral("merge_back"), m_syncView, SLOT(mergeBack()));
     action->setText(i18nc("@action:inmenu", "Copy to merging source"));
@@ -700,47 +659,45 @@ void EditorTab::showDocks()
 {
 }
 
-void EditorTab::setProperCaption(QString title, bool modified)
-{
-    if (m_catalog->autoSaveRecovered())
-        title += i18nc("editor tab title addition", " (recovered)");
-    setWindowTitle(title + QStringLiteral(" [*]"));
-    setWindowModified(modified);
-}
-
 void EditorTab::setFullPathShown(bool fullPathShown)
 {
     m_fullPathShown = fullPathShown;
 
     updateCaptionPath();
-    setModificationSign();
+    updateTabLabelAndIcon();
 }
 
-void EditorTab::setModificationSign()
+void EditorTab::updateTabLabelAndIcon()
 {
-    bool clean = m_catalog->isClean() && !m_syncView->isModified() && !m_syncViewSecondary->isModified();
-    setProperCaption(_captionPath, !clean);
+    m_tabIcon = isClean() ? m_defaultTabIcon : m_unsavedTabIcon;
+    m_tabToolTip = m_catalog->url();
+    m_tabLabel = m_relativeOrAbsoluteFilePath;
+    if (m_catalog->autoSaveRecovered())
+        m_tabLabel += i18nc("editor tab title addition", " (recovered)");
+
+    Q_EMIT signalUpdatedTabLabelAndIconAvailable(qobject_cast<LokalizeTabPageBase *>(this));
 }
 
 void EditorTab::updateCaptionPath()
 {
     QString url = m_catalog->url();
+    m_tabToolTip = url;
     if (!m_project->isLoaded()) {
-        _captionPath = url;
+        m_relativeOrAbsoluteFilePath = url;
         return;
     }
     if (!m_fullPathShown) {
-        _captionPath = QFileInfo(url).fileName();
+        m_relativeOrAbsoluteFilePath = QFileInfo(url).fileName();
         return;
     }
-    _captionPath = QDir(QFileInfo(m_project->path()).absolutePath()).relativeFilePath(url);
-    if (_captionPath.contains(QLatin1String("../..")))
-        _captionPath = url;
-    else if (_captionPath.startsWith(QLatin1String("./")))
-        _captionPath = _captionPath.mid(2);
+    m_relativeOrAbsoluteFilePath = QDir(QFileInfo(m_project->path()).absolutePath()).relativeFilePath(url);
+    if (m_relativeOrAbsoluteFilePath.contains(QLatin1String("../..")))
+        m_relativeOrAbsoluteFilePath = url;
+    else if (m_relativeOrAbsoluteFilePath.startsWith(QLatin1String("./")))
+        m_relativeOrAbsoluteFilePath = m_relativeOrAbsoluteFilePath.mid(2);
 }
 
-bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QString, QMdiSubWindow *> openedFiles, bool silent)
+bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QString, EditorTab *> openedFiles, bool silent)
 {
     if (!m_catalog->isClean()) {
         switch (KMessageBox::warningTwoActionsCancel(SettingsController::instance()->mainWindowPtr(),
@@ -766,16 +723,10 @@ bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QStrin
 
     QString saidPath;
     if (filePath.isEmpty()) {
-        // Prevent crashes
-        // Project::instance()->model()->weaver()->suspend();
-        // KDE5PORT use mutex if the crash is still there with kfilemetadata library
         filePath = QFileDialog::getOpenFileName(SettingsController::instance()->mainWindowPtr(),
                                                 i18nc("@title:window", "Select translation file"),
                                                 suggestedDirPath,
-                                                Catalog::supportedFileTypes(true)); //" text/x-gettext-translation-template");
-        // Project::instance()->model()->weaver()->resume();
-        // TODO application/x-xliff, windows: just extensions
-        // originalPath=url.path(); never used
+                                                Catalog::supportedFileTypes(true));
     } else if (!QFile::exists(filePath) && Project::instance()->isLoaded()) {
         // check if we are opening template
         QString newPath = filePath;
@@ -787,7 +738,7 @@ bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QStrin
     }
     if (filePath.isEmpty())
         return false;
-    QMap<QString, QMdiSubWindow *>::const_iterator it = openedFiles.constFind(filePath);
+    QMap<QString, EditorTab *>::const_iterator it = openedFiles.constFind(filePath);
     if (it != openedFiles.constEnd()) {
         qCWarning(LOKALIZE_LOG) << "already opened:" << filePath;
         return false;
@@ -814,7 +765,7 @@ bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QStrin
 
         m_currentPos.entry = -1; // so the signals are emitted
         DocPosition pos(0);
-        // we delay gotoEntry(pos) until project is loaded;
+        // we delay gotoEntry(pos) until project is loaded
 
         // Project
         if (!m_project->isLoaded()) {
@@ -838,19 +789,17 @@ bool EditorTab::fileOpen(QString filePath, QString suggestedDirPath, QMap<QStrin
                 if (m_project->desirablePath().isEmpty())
                     m_project->setDesirablePath(fileInfo.absolutePath() + QStringLiteral("/index.lokalize"));
 
-                if (m_catalog->targetLangCode().isEmpty() /*&& m_project->targetLangCode().length()*/)
+                if (m_catalog->targetLangCode().isEmpty())
                     m_catalog->setTargetLangCode(getTargetLangCode(fileInfo.fileName()));
-
-                //_project->setLangCode(m_catalog->targetLangCode());
             }
         }
-        if (m_catalog->targetLangCode().isEmpty() /*&& m_project->targetLangCode().length()*/)
+        if (m_catalog->targetLangCode().isEmpty())
             m_catalog->setTargetLangCode(Project::instance()->targetLangCode());
 
         gotoEntry(pos);
 
         updateCaptionPath();
-        setModificationSign();
+        updateTabLabelAndIcon();
 
         // OK!!!
         Q_EMIT xliffFileOpened(m_catalog->type() == Xliff);
@@ -883,8 +832,7 @@ bool EditorTab::saveFileAs(const QString &defaultPath)
 
 bool EditorTab::saveFile(const QString &filePath)
 {
-    bool clean = m_catalog->isClean() && !m_syncView->isModified() && !m_syncViewSecondary->isModified() && filePath == m_catalog->url();
-    if (clean)
+    if (isClean() && filePath == m_catalog->url())
         return true;
     if (m_catalog->isClean() && filePath.isEmpty()) {
         Q_EMIT m_catalog->signalFileSaved();
@@ -892,7 +840,7 @@ bool EditorTab::saveFile(const QString &filePath)
     }
     if (m_catalog->saveToUrl(filePath)) {
         updateCaptionPath();
-        setModificationSign();
+        updateTabLabelAndIcon();
         Q_EMIT fileSaved(filePath);
         return true;
     }
@@ -925,30 +873,12 @@ EditorState EditorTab::state()
     state.filePath = m_catalog->url();
     state.mergeFilePath = m_syncView->filePath();
     state.entry = m_currentPos.entry;
-    // state.offset=_currentPos.offset;
     return state;
 }
 
-bool EditorTab::queryClose()
+bool EditorTab::isClean()
 {
-    const bool clean = m_catalog->isClean() && !m_syncView->isModified() && !m_syncViewSecondary->isModified();
-    if (clean)
-        return true;
-
-    switch (KMessageBox::warningTwoActionsCancel(this,
-                                                 i18nc("@info",
-                                                       "The document contains unsaved changes.\n"
-                                                       "Do you want to save your changes or discard them?"),
-                                                 i18nc("@title:window", "Warning"),
-                                                 KStandardGuiItem::save(),
-                                                 KStandardGuiItem::discard())) {
-    case KMessageBox::PrimaryAction:
-        return saveFile();
-    case KMessageBox::SecondaryAction:
-        return true;
-    default:
-        return false;
-    }
+    return m_catalog->isClean() && !m_syncView->isModified() && !m_syncViewSecondary->isModified();
 }
 
 void EditorTab::undo()
@@ -1009,8 +939,6 @@ void EditorTab::gotoEntry(DocPosition pos, int selection)
     if (pos.part == DocPosition::UndefPart)
         m_currentPos.part = DocPosition::Target;
 
-    // QTime time; time.start();
-
     if (newEntry) {
         m_currentPos = pos;
         if (true) {
@@ -1039,7 +967,6 @@ void EditorTab::gotoEntry(DocPosition pos, int selection)
     }
 
     statusBarItems.insert(ID_STATUS_CURRENT, i18nc("@info:status", "Current: %1", m_currentPos.entry + 1));
-    // qCDebug(LOKALIZE_LOG)<<"ELA "<<time.elapsed();
 }
 
 void EditorTab::msgStrChanged()
@@ -1057,9 +984,6 @@ void EditorTab::msgStrChanged()
     else
         msg = i18nc("@info:status 'fuzzy' in gettext terminology", "Needs review");
 
-    /*    else
-            statusBar()->changeItem("",ID_STATUS_ISFUZZY);*/
-
     statusBarItems.insert(ID_STATUS_ISFUZZY, msg);
 
     m_currentIsUntr = isUntr;
@@ -1317,16 +1241,6 @@ void EditorTab::mergeOpen(QString mergeFilePath)
     m_syncView->mergeOpen(mergeFilePath);
 }
 
-// HACK to prevent redundant repaintings when widget isn't visible
-void EditorTab::paintEvent(QPaintEvent *event)
-{
-    if (QMdiSubWindow *sw = qobject_cast<QMdiSubWindow *>(parent())) {
-        if (sw->mdiArea()->currentSubWindow() != sw)
-            return;
-    }
-    LokalizeSubwindowBase2::paintEvent(event);
-}
-
 void EditorTab::indexWordsForCompletion()
 {
     CompletionStorage::instance()->scanCatalog(m_catalog);
@@ -1612,7 +1526,7 @@ void EditorTab::mergeIntoOpenDocument()
         originalOdfFilePath = QFileDialog::getOpenFileName(SettingsController::instance()->mainWindowPtr(),
                                                            i18n("Select original OpenDocument on which current XLIFF file is based"),
                                                            xliffFolder,
-                                                           i18n("OpenDocument files (*.odt *.ods)") /*"text/x-lokalize-project"*/);
+                                                           i18n("OpenDocument files (*.odt *.ods)"));
         if (originalOdfFilePath.length())
             m_catalog->setOriginalOdfFilePath(originalOdfFilePath);
     }
@@ -1637,39 +1551,34 @@ void EditorTab::mergeIntoOpenDocument()
     if (!QFile::exists(args.at(1)))
         return;
 
-    // if (originalOdfFileInfo.suffix().toLower()==QLatin1String(".odt"))
-    {
-        const QString lowriter = QStandardPaths::findExecutable(QStringLiteral("soffice"));
-        if (lowriter.isEmpty()) {
-            return;
-        }
+    const QString lowriter = QStandardPaths::findExecutable(QStringLiteral("soffice"));
+    if (lowriter.isEmpty()) {
+        return;
+    }
 
-        if (QProcess::execute(lowriter, QStringList(QStringLiteral("--version"))) == -2) {
-            // TODO
-            // KMessageBox::error(SettingsController::instance()->mainWindowPtr(), i18n("Install translate-toolkit package and retry"));
-            return;
-        }
-        QProcess::startDetached(lowriter, QStringList(args.at(1)));
-        QString reloaderScript = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("scripts/odf/xliff2odf-standalone.py"));
-        if (reloaderScript.length()) {
-            QString python = QStandardPaths::findExecutable(QStringLiteral("python"));
+    if (QProcess::execute(lowriter, QStringList(QStringLiteral("--version"))) == -2) {
+        return;
+    }
+    QProcess::startDetached(lowriter, QStringList(args.at(1)));
+    QString reloaderScript = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("scripts/odf/xliff2odf-standalone.py"));
+    if (reloaderScript.length()) {
+        QString python = QStandardPaths::findExecutable(QStringLiteral("python"));
+        QStringList unoArgs(QStringLiteral("-c"));
+        unoArgs.append(QStringLiteral("import uno"));
+        if (python.isEmpty() || QProcess::execute(python, unoArgs) != 0) {
+            python = QStandardPaths::findExecutable(QStringLiteral("python3"));
             QStringList unoArgs(QStringLiteral("-c"));
             unoArgs.append(QStringLiteral("import uno"));
             if (python.isEmpty() || QProcess::execute(python, unoArgs) != 0) {
-                python = QStandardPaths::findExecutable(QStringLiteral("python3"));
-                QStringList unoArgs(QStringLiteral("-c"));
-                unoArgs.append(QStringLiteral("import uno"));
-                if (python.isEmpty() || QProcess::execute(python, unoArgs) != 0) {
-                    KMessageBox::information(SettingsController::instance()->mainWindowPtr(), i18n("Install python-uno package for additional functionality."));
-                    return;
-                }
+                KMessageBox::information(SettingsController::instance()->mainWindowPtr(), i18n("Install python-uno package for additional functionality."));
+                return;
             }
-
-            QStringList reloaderArgs(reloaderScript);
-            reloaderArgs.append(args.at(1));
-            reloaderArgs.append(currentEntryId());
-            QProcess::execute(python, reloaderArgs);
         }
+
+        QStringList reloaderArgs(reloaderScript);
+        reloaderArgs.append(args.at(1));
+        reloaderArgs.append(currentEntryId());
+        QProcess::execute(python, reloaderArgs);
     }
 }
 
@@ -1767,15 +1676,15 @@ void EditorTab::addTemporaryEntryNote(int entry, const QString &note)
 
 void EditorTab::addAlternateTranslation(int entry, const QString &translation)
 {
-    m_altTransView->addAlternateTranslation(entry, translation);
+    m_alternateTranslationView->addAlternateTranslation(entry, translation);
 }
 void EditorTab::addTemporaryAlternateTranslation(int entry, const QString &translation)
 {
-    m_altTransView->addAlternateTranslation(entry, translation);
+    m_alternateTranslationView->addAlternateTranslation(entry, translation);
 }
 void EditorTab::attachAlternateTranslationFile(const QString &path)
 {
-    m_altTransView->attachAltTransFile(path);
+    m_alternateTranslationView->attachAltTransFile(path);
 }
 
 void EditorTab::setEntryTarget(int entry, int form, const QString &content)
