@@ -14,13 +14,13 @@
 #include <config.h>
 #endif
 
-#include "lokalizesubwindowbase.h"
+#include "lokalizetabpagebase.h"
 #include "pos.h"
 
 #include <KProcess>
+
 #include <QHash>
 #include <QMap>
-#include <QMdiSubWindow>
 
 namespace Sonnet
 {
@@ -30,6 +30,10 @@ namespace Sonnet
 {
 class BackgroundChecker;
 }
+namespace TM
+{
+class TMView;
+}
 
 #include <kxmlguiclient.h>
 
@@ -70,7 +74,6 @@ public:
     QString filePath;
     QString mergeFilePath;
     int entry;
-    // int offset;
 };
 
 /**
@@ -83,7 +86,7 @@ public:
  *
  * @author Nick Shaforostoff <shafff@ukr.net>
  */
-class EditorTab : public LokalizeSubwindowBase2
+class EditorTab : public LokalizeTabPageBase
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.Lokalize.Editor")
@@ -99,12 +102,11 @@ public:
     void showDocks() override;
     QString currentFilePath() override;
     void setFullPathShown(bool);
-    void setProperCaption(QString, bool); // reimpl to remove ' - Lokalize'
+
 public Q_SLOTS:
     void setProperFocus();
 
 public:
-    bool queryClose() override;
     EditorState state();
     KXMLGUIClient *guiClient() override
     {
@@ -125,8 +127,21 @@ public:
 
     bool fileOpen(QString filePath = QString(),
                   QString suggestedDirPath = QString(),
-                  QMap<QString, QMdiSubWindow *> openedFiles = QMap<QString, QMdiSubWindow *>(),
+                  QMap<QString, EditorTab *> openedFiles = QMap<QString, EditorTab *>(),
                   bool silent = false);
+
+    void setModificationSign();
+    /*
+     * @short Checks editor tab is ready to close
+     * @return false if a part of the editor tab has
+     * unsaved data.
+     * @author Finley Watson
+     */
+    bool isClean();
+
+    QIcon m_defaultTabIcon;
+    QIcon m_unsavedTabIcon;
+
 public Q_SLOTS:
     // for undo/redo, views
     void gotoEntry(DocPosition pos);
@@ -230,8 +245,7 @@ private Q_SLOTS:
     void numberOfUntranslatedChanged();
     // fuzzy, untr [statusbar] indication
     void msgStrChanged();
-    // modif [caption] indication
-    void setModificationSign();
+    void updateTabLabelAndIcon();
     void updateCaptionPath();
 
     // gui
@@ -248,12 +262,6 @@ private Q_SLOTS:
     void doReplace(const QString &, int, int, int); // internal
     void cleanupReplace(); // internal
 
-    //     void selectAll();
-    //     void deselectAll();
-    //     void clear();
-    //     void search2msgstr();
-    //     void plural2msgstr();
-
     void gotoEntry();
 
     void gotoPrevFuzzyUntr();
@@ -295,9 +303,6 @@ private Q_SLOTS:
 
     void pologyHasFinished(int exitCode, QProcess::ExitStatus exitStatus);
 
-protected:
-    void paintEvent(QPaintEvent *event) override;
-
 private:
     void setupAccel();
     void setupActions();
@@ -343,10 +348,11 @@ private:
     MergeView *m_syncViewSecondary{};
     CatalogView *m_transUnitsView{};
     MsgCtxtView *m_notesView{};
-    AltTransView *m_altTransView{};
+    AltTransView *m_alternateTranslationView{};
+    TM::TMView *m_translationMemoryView{};
     // END views
 
-    QString _captionPath;
+    QString m_relativeOrAbsoluteFilePath;
 
     bool m_srcFileOpenRequestAccepted{};
 
