@@ -48,7 +48,12 @@
 #endif
 
 using namespace TM;
-// static int BIG_COUNTER=0;
+
+static void copy(Ui_QueryOptions *ui_queryOptions, int column)
+{
+    QApplication::clipboard()->setText(
+        ui_queryOptions->treeView->currentIndex().sibling(ui_queryOptions->treeView->currentIndex().row(), column).data().toString());
+}
 
 // TODO do things for case when user explicitly wants to find & accel mark
 
@@ -113,8 +118,6 @@ void TMDBModel::setFilter(const QString &source, const QString &target, bool inv
             targetQuery =
                 QStringLiteral("AND target_strings.target ") + invertTargetStr + QStringLiteral("LIKE '%") + escapedTarget + QStringLiteral("%' ESCAPE '\b' ");
     } else if (m_queryType == WordOrder) {
-        /*escapedSource.replace('%',"\b%");escapedSource.replace('_',"\b_");
-        escapedTarget.replace('%',"\b%");escapedTarget.replace('_',"\b_");*/
         const QRegularExpression wre(QStringLiteral("\\W"), QRegularExpression::UseUnicodePropertiesOption);
         QStringList sourceList = escapedSource.split(wre, Qt::SkipEmptyParts);
         QStringList targetList = escapedTarget.split(wre, Qt::SkipEmptyParts);
@@ -182,7 +185,6 @@ bool TMDBModel::rowIsApproved(int row) const
 
 int TMDBModel::translationStatus(const QModelIndex &item) const
 {
-    // QMutexLocker locker(&m_dbOperationMutex);
     if (QSqlQueryModel::data(item.sibling(item.row(), Target), Qt::DisplayRole).toString().isEmpty())
         return 2;
     return int(!rowIsApproved(item.row()));
@@ -191,7 +193,6 @@ int TMDBModel::translationStatus(const QModelIndex &item) const
 #define TM_DELIMITER '\v'
 QVariant TMDBModel::data(const QModelIndex &item, int role) const
 {
-    // QMutexLocker locker(&m_dbOperationMutex);
     bool doHtml = (role == FastSizeHintItemDelegate::HtmlDisplayRole);
     if (doHtml)
         role = Qt::DisplayRole;
@@ -205,8 +206,6 @@ QVariant TMDBModel::data(const QModelIndex &item, int role) const
         return translationStatus(item);
 
     QVariant result = QSqlQueryModel::data(item, role);
-    /*    if (role==Qt::SizeHintRole && !result.isValid())
-            BIG_COUNTER++;*/
     if (role != Qt::DisplayRole)
         return result;
 
@@ -261,7 +260,6 @@ protected:
 private:
     QVector<Rule> m_rules;
     mutable QMap<int, int> m_matchingRulesForSourceRow;
-    // mutable QMap<int, QVector<StartLen> > m_highlightDataForSourceRow;
 };
 
 bool TMResultsSortFilterProxyModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
@@ -322,8 +320,6 @@ QVariant TMResultsSortFilterProxyModel::data(const QModelIndex &index, int role)
             return string.replace(match.capturedStart(), match.capturedLength(), QStringLiteral("<b>") + match.capturedView(0) + QStringLiteral("</b>"));
     }
 
-    // StartLen sl=m_highlightDataForSourceRow.value(source_row).at(index.column());
-
     return result;
 }
 
@@ -371,11 +367,11 @@ QVariant QueryStylesModel::data(const QModelIndex &item, int role) const
 
 // BEGIN TMWindow
 TMTab::TMTab(QWidget *parent)
-    : LokalizeSubwindowBase2(parent)
+    : LokalizeTabPageBase(parent)
     , m_proxyModel(new TMResultsSortFilterProxyModel(this))
 {
-    // setCaption(i18nc("@title:window","Translation Memory"),false);
-    setWindowTitle(i18nc("@title:window", "Translation Memory"));
+    m_tabLabel = i18nc("@title:tab", "Translation Memory");
+    m_tabIcon = QIcon::fromTheme(QLatin1String("server-database"));
     setAcceptDrops(true);
 
     ui_queryOptions = new Ui_QueryOptions;
@@ -416,11 +412,6 @@ TMTab::TMTab(QWidget *parent)
     connect(view, &QTreeView::activated, this, &TMTab::openFile);
     view->addAction(a);
 
-    // view->addAction(KStandardAction::copy(this),this,SLOT(),this);
-    // QKeySequence::Copy?
-    // QShortcut* shortcut = new QShortcut(Qt::ControlModifier | Qt::Key_P,view,0,0,Qt::WidgetWithChildrenShortcut);
-    // connect(shortcut,SIGNAL(activated()), this, SLOT(copyText()));
-
     m_model = new TMDBModel(this);
     m_model->setDB(Project::instance()->projectID());
 
@@ -545,7 +536,6 @@ void TMTab::handleResults()
 {
     QApplication::restoreOverrideCursor();
     QString filemask = ui_queryOptions->filemask->text();
-    // ui_queryOptions->regexSource->text(),ui_queryOptions->regexTarget->text()
     m_model->m_dbOperationMutex.lock();
     int rowCount = m_model->rowCount();
     m_model->m_dbOperationMutex.unlock();
@@ -594,12 +584,6 @@ void TMTab::displayTotalResultCount()
     m_model->m_dbOperationMutex.unlock();
 }
 
-static void copy(Ui_QueryOptions *ui_queryOptions, int column)
-{
-    QApplication::clipboard()->setText(
-        ui_queryOptions->treeView->currentIndex().sibling(ui_queryOptions->treeView->currentIndex().row(), column).data().toString());
-}
-
 void TMTab::copySource()
 {
     copy(ui_queryOptions, TMDBModel::Source);
@@ -646,55 +630,11 @@ void TMTab::setQAMode(bool enable)
 
     m_proxyModel->setRules(m_qaView->rules());
 
-    /*QDomElement docElem = m_categories.at(0).toElement();
-
-    QDomNode n = docElem.firstChildElement();
-    while(!n.isNull())
-    {
-        QDomElement e = n.toElement();
-        qCDebug(LOKALIZE_LOG) << e.tagName();
-        n = n.nextSiblingElement();
-    }*/
-
     performQuery();
 }
 
 // END TMWindow
 
-#if 0
-bool QueryResultDelegate::editorEvent(QEvent* event,
-                                      QAbstractItemModel* model,
-                                      const QStyleOptionViewItem& /*option*/,
-                                      const QModelIndex& index)
-{
-    qCWarning(LOKALIZE_LOG) << "QEvent" << event;
-    if (event->type() == QEvent::Shortcut) {
-        qCWarning(LOKALIZE_LOG) << "QEvent::Shortcut" << index.data().canConvert(QVariant::String);
-        if (static_cast<QShortcutEvent*>(event)->key().matches(QKeySequence::Copy)
-            && index.data().canConvert(QVariant::String)) {
-            QApplication::clipboard()->setText(index.data().toString());
-            qCWarning(LOKALIZE_LOG) << "index.data().toString()";
-        }
-    } else if (event->type() == QEvent::MouseButtonRelease) {
-        QMouseEvent* mEvent = static_cast<QMouseEvent*>(event);
-        if (mEvent->button() == Qt::MiddleButton) {
-        }
-    } else if (event->type() == QEvent::KeyPress) {
-        QKeyEvent* kEvent = static_cast<QKeyEvent*>(event);
-        if (kEvent->key() == Qt::Key_Return) {
-            if (kEvent->modifiers() == Qt::NoModifier) {
-            }
-        }
-    } else
-        return false;
-
-    event->accept();
-    return true;
-
-}
-
-#endif
-
 void TMTab::dragEnterEvent(QDragEnterEvent *event)
 {
     if (dragIsAcceptable(event->mimeData()->urls()))
@@ -745,11 +685,6 @@ void TMTab::lookup(QString source, QString target)
     performQuery();
 }
 
-// void TMTab::lookup(DocPosition::Part part, QString text)
-// {
-//     lookup(part==DocPosition::Source?text:QString(),part==DocPosition::Target?text:QString());
-// }
-
 bool TMTab::findGuiTextPackage(QString text, QString package)
 {
     qCWarning(LOKALIZE_LOG) << package << text;
